# ILStrap

ilstrap is a bootstrap for IDA Loaders to simplify/standardize the installation and initialization process

it has cross-platform support for installing IDA loaders, including ones that have several modules.